translate.lang.ta

Package translate :: Package lang :: Module ta |
[hide private]
[frames] | no frames]

# Source Code for Module translate.lang.ta

     1  #!/usr/bin/env python
     2  # -*- coding: utf-8 -*-
     3  #
     4  # Copyright 2010 Zuza Software Foundation
     5  #
     6  # This file is part of Virtaal.
     7  #
     8  # This program is free software; you can redistribute it and/or modify
     9  # it under the terms of the GNU General Public License as published by
    10  # the Free Software Foundation; either version 2 of the License, or
    11  # (at your option) any later version.
    12  #
    13  # This program is distributed in the hope that it will be useful,
    14  # but WITHOUT ANY WARRANTY; without even the implied warranty of
    15  # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    16  # GNU General Public License for more details.
    17  #
    18  # You should have received a copy of the GNU General Public License
    19  # along with this program; if not, see <http://www.gnu.org/licenses/>.
    20
    21  """This module represents Tamil language.
    22
    23  For more information, see U{http://en.wikipedia.org/wiki/Tamil_language}
    24  """
    25
    26  from translate.lang import common
    27
    28
    29 -class ta(common.Common):
    30      """This class represents Tamil."""
    31
    32      ignoretests = ["startcaps", "simplecaps"]
    33